==> buildpack-client-0.0.12-sources.jar: dev/snowdrop/buildpack/config/DockerConfigBuilder.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class DockerConfigBuilder extends dev.snowdrop.buildpack.config.DockerConfigFluentImpl<dev.snowdrop.buildpack.config.DockerConfigBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.config.DockerConfig,dev.snowdrop.buildpack.config.DockerConfigBuilder>{
  public DockerConfigBuilder() {
    this(false);
  }
  public DockerConfigBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,dev.snowdrop.buildpack.config.DockerConfig instance) {
    this(fluent, instance, false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,dev.snowdrop.buildpack.config.DockerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPullTimeoutSeconds(instance.getPullTimeoutSeconds()); 
    fluent.withPullRetryCount(instance.getPullRetryCount()); 
    fluent.withPullRetryIncreaseSeconds(instance.getPullRetryIncreaseSeconds()); 
    fluent.withPullPolicy(instance.getPullPolicy()); 
    fluent.withDockerHost(instance.getDockerHost()); 
    fluent.withDockerSocket(instance.getDockerSocket()); 
    fluent.withDockerNetwork(instance.getDockerNetwork()); 
    fluent.withUseDaemon(instance.getUseDaemon()); 
    fluent.withDockerClient(instance.getDockerClient()); 
    this.validationEnabled = validationEnabled; 
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfig instance) {
    this(instance,false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPullTimeoutSeconds(instance.getPullTimeoutSeconds()); 
    this.withPullRetryCount(instance.getPullRetryCount()); 
    this.withPullRetryIncreaseSeconds(instance.getPullRetryIncreaseSeconds()); 
    this.withPullPolicy(instance.getPullPolicy()); 
    this.withDockerHost(instance.getDockerHost()); 
    this.withDockerSocket(instance.getDockerSocket()); 
    this.withDockerNetwork(instance.getDockerNetwork()); 
    this.withUseDaemon(instance.getUseDaemon()); 
    this.withDockerClient(instance.getDockerClient()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.config.EditableDockerConfig build() {
    EditableDockerConfig buildable = new EditableDockerConfig(fluent.getPullTimeoutSeconds(),fluent.getPullRetryCount(),fluent.getPullRetryIncreaseSeconds(),fluent.getPullPolicy(),fluent.getDockerHost(),fluent.getDockerSocket(),fluent.getDockerNetwork(),fluent.getUseDaemon(),fluent.getDockerClient());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DockerConfigBuilder that = (DockerConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.14-sources.jar: dev/snowdrop/buildpack/config/DockerConfigBuilder.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class DockerConfigBuilder extends dev.snowdrop.buildpack.config.DockerConfigFluentImpl<dev.snowdrop.buildpack.config.DockerConfigBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.config.DockerConfig,dev.snowdrop.buildpack.config.DockerConfigBuilder>{
  public DockerConfigBuilder() {
    this(false);
  }
  public DockerConfigBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,dev.snowdrop.buildpack.config.DockerConfig instance) {
    this(fluent, instance, false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent,dev.snowdrop.buildpack.config.DockerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPullTimeoutSeconds(instance.getPullTimeoutSeconds()); 
    fluent.withPullRetryCount(instance.getPullRetryCount()); 
    fluent.withPullRetryIncreaseSeconds(instance.getPullRetryIncreaseSeconds()); 
    fluent.withPullPolicy(instance.getPullPolicy()); 
    fluent.withDockerHost(instance.getDockerHost()); 
    fluent.withDockerSocket(instance.getDockerSocket()); 
    fluent.withDockerNetwork(instance.getDockerNetwork()); 
    fluent.withUseDaemon(instance.getUseDaemon()); 
    fluent.withDockerClient(instance.getDockerClient()); 
    fluent.withAuthConfigs(instance.getAuthConfigs()); 
    this.validationEnabled = validationEnabled; 
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfig instance) {
    this(instance,false);
  }
  public DockerConfigBuilder(dev.snowdrop.buildpack.config.DockerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPullTimeoutSeconds(instance.getPullTimeoutSeconds()); 
    this.withPullRetryCount(instance.getPullRetryCount()); 
    this.withPullRetryIncreaseSeconds(instance.getPullRetryIncreaseSeconds()); 
    this.withPullPolicy(instance.getPullPolicy()); 
    this.withDockerHost(instance.getDockerHost()); 
    this.withDockerSocket(instance.getDockerSocket()); 
    this.withDockerNetwork(instance.getDockerNetwork()); 
    this.withUseDaemon(instance.getUseDaemon()); 
    this.withDockerClient(instance.getDockerClient()); 
    this.withAuthConfigs(instance.getAuthConfigs()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.config.DockerConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.config.EditableDockerConfig build() {
    EditableDockerConfig buildable = new EditableDockerConfig(fluent.getPullTimeoutSeconds(),fluent.getPullRetryCount(),fluent.getPullRetryIncreaseSeconds(),fluent.getPullPolicy(),fluent.getDockerHost(),fluent.getDockerSocket(),fluent.getDockerNetwork(),fluent.getUseDaemon(),fluent.getDockerClient(),fluent.getAuthConfigs());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DockerConfigBuilder that = (DockerConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
